==> appboxo_sdk-0.1.17.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:appboxo_sdk/appboxo_sdk.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  Future<void> Function() subscription;

  @override
  void dispose() {
    subscription();
    super.dispose();
  }

  @override
  void initState() {
    super.initState();
    Appboxo.setConfig("CLIENT_ID", multitaskMode: false);
    //'multitaskMode' works only on Android. By default 'true', each miniapp appears as a task in the Recents screen.
    Appboxo.customEvents().listen((CustomEvent event) {
      if (event.appId == 'app16973') {
        Appboxo.hideMiniapps();
        Future.delayed(const Duration(milliseconds: 2000), () {
          Appboxo.openMiniapp("app16973", "");
          event.payload = {"complete": "ok"};
          Appboxo.sendEvent(event);
        });
      }
    });
    subscription = Appboxo.lifecycleHooksListener(
      onLaunch: (appId) {
        print(appId);
        print('onLaunch');
      },
      onResume: (appId) {
        print(appId);
        print('onResume');
      },
      onPause: (appId) {
        print(appId);
        print('onPause');
      },
      onClose: (appId) {
        print(appId);
        print('onClose');
      },
      onError: (appId, error) {
        print(appId);
        print(error);
        print('onError');
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Appboxo SDK Test'),
        ),
        body: Center(
          child: RaisedButton(
            onPressed: () {
              Appboxo.openMiniapp("app16973", "");
            },
            padding: const EdgeInsets.all(16),
            color: Colors.blue,
            child: const Text(
              'Run miniapp',
              style: const TextStyle(
                color: Colors.white,
                fontSize: 16,
              ),
            ),
          ),
        ),
      ),
    );
  }
}

==> appboxo_sdk-0.1.18.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:appboxo_sdk/appboxo_sdk.dart';
import 'package:fluttertoast/fluttertoast.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  Future<void> Function()? subscription;

  @override
  void dispose() {
    subscription?.call();
    super.dispose();
  }

  @override
  void initState() {
    super.initState();
    Appboxo.setConfig("602248", multitaskMode: false);
    //'multitaskMode' works only on Android. By default 'true', each miniapp appears as a task in the Recents screen.
    Appboxo.customEvents().listen((CustomEvent event) {
      print(event.toJson().toString());
      Fluttertoast.showToast(
        msg: event.payload["message"] ?? event.type,
        toastLength: Toast.LENGTH_SHORT,
        timeInSecForIosWeb: 1,
        backgroundColor: Colors.black,
        textColor: Colors.white,
        fontSize: 16.0,
      );
      Appboxo.sendEvent(event);
    });
    Appboxo.paymentEvents().listen((event) {
      event.status = "success";
      Appboxo.sendPaymentEvent(event);
    });
    subscription = Appboxo.lifecycleHooksListener(
      onAuth: (appId) {
        print(appId);
        print('onAuth');
      },
      onLaunch: (appId) {
        print(appId);
        print('onLaunch');
      },
      onResume: (appId) {
        print(appId);
        print('onResume');
      },
      onPause: (appId) {
        print(appId);
        print('onPause');
      },
      onClose: (appId) {
        print(appId);
        print('onClose');
      },
      onError: (appId, error) {
        print(appId);
        print(error);
        print('onError');
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Appboxo SDK Test'),
        ),
        body: Center(
          child: ElevatedButton(
            onPressed: () {
              Appboxo.openMiniapp("app16973");
            },
            child: const Text(
              'Run miniapp',
              style: const TextStyle(
                color: Colors.white,
                fontSize: 16,
              ),
            ),
          ),
        ),
      ),
    );
  }
}
